==> cdebootstrap_0.3.15ubuntu1.tar.gz: cdebootstrap-0.3.15ubuntu1/include/suite.h <==
/*
 * suite.h
 *
 * Copyright (C) 2003 Bastian Blank <waldi@debian.org>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 *
 * $LastChangedBy: bastian $
 * $LastChangedDate: 2006-10-20 12:21:07 +0000 (Fr, 20 Okt 2006) $
 * $LastChangedRevision: 1273 $
 */

#ifndef SUITE_H
#define SUITE_H

#include "packages.h"
#include "suite_config.h"

extern struct suite_config *suite;
extern const char *arch;
extern const char *flavour;
extern const char *suite_name;
extern const char *configdir;

int suite_init (const char *suite_name, const char *suite_config_name, const char *arch, const char *flavour, const char **include, unsigned int include_size, const char *configdir);
int suite_init_second (const char *suite_name);
int suite_install (di_packages *packages, di_packages_allocator *allocator, di_slist *install);
di_slist *suite_packages_list (di_packages *packages, di_packages_allocator *allocator);

#endif

==> cdebootstrap_0.4.4ubuntu1.tar.gz: cdebootstrap-0.4.4ubuntu1/include/suite.h <==
/*
 * suite.h
 *
 * Copyright (C) 2003 Bastian Blank <waldi@debian.org>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 *
 * $LastChangedBy: bastian $
 * $LastChangedDate: 2007-05-13 18:45:38 +0000 (So, 13 Mai 2007) $
 * $LastChangedRevision: 1440 $
 */

#ifndef SUITE_H
#define SUITE_H

#include <debian-installer.h>
#include <stdbool.h>

#include "packages.h"
#include "suite_config.h"

extern struct suites_config_suite *suites_suite;
extern struct suite_config *suite;
extern const char *arch;
extern const char *flavour;
extern const char *suite_name;
extern bool authentication;
extern const char *keyring;

int suite_init (const char *suite_name, const char *suite_config_name, const char *arch, const char *flavour, di_slist *include, di_slist *exclude, const char *configdir, bool authentication, const char *keyring_name, const char **keyringdirs);
int suite_install (di_packages *packages, di_packages_allocator *allocator, di_slist *install);
di_slist *suite_packages_list (di_packages *packages, di_packages_allocator *allocator);

#endif
